# <span class="badge package-core"></span> rolebinding

## Objects

 * <span class="badge object-type-class"></span> [BuiltinRoleRef](./object-BuiltinRoleRef.md)
 * <span class="badge object-type-class"></span> [CustomRoleRef](./object-CustomRoleRef.md)
 * <span class="badge object-type-class"></span> [RoleBinding](./object-RoleBinding.md)
 * <span class="badge object-type-class"></span> [RoleBindingSubject](./object-RoleBindingSubject.md)
## Builders

 * <span class="badge builder"></span> [BuiltinRoleRef](./builder-BuiltinRoleRef.md)
 * <span class="badge builder"></span> [CustomRoleRef](./builder-CustomRoleRef.md)
 * <span class="badge builder"></span> [RoleBinding](./builder-RoleBinding.md)
 * <span class="badge builder"></span> [RoleBindingSubject](./builder-RoleBindingSubject.md)
